@@ -1,7 +1,6 @@
 import django.contrib.admin
-from django.contrib.admin.apps import SimpleAdminConfig, AppConfig
+from django.contrib.admin.apps import AppConfig, SimpleAdminConfig
 from django.contrib.auth import get_user_model
-
 from django.utils.translation import gettext_lazy as _
 
 
@@ -17,12 +16,13 @@ class SmartAuthConfig(AppConfig):
     name = 'smart_admin.smart_auth'
 
     def ready(self):
-        from smart_admin.smart_auth.admin import GroupAdmin, UserAdmin, PermissionAdmin, ContentTypeAdmin
-        from smart_admin.decorators import smart_register
         from django.contrib.auth.models import Group, Permission
-        from django.contrib.auth.models import Permission
         from django.contrib.contenttypes.models import ContentType
 
+        from smart_admin.decorators import smart_register
+        from smart_admin.smart_auth.admin import (ContentTypeAdmin, GroupAdmin,
+                                                  PermissionAdmin, UserAdmin,)
+
         smart_register(Group)(GroupAdmin)
         smart_register(get_user_model())(UserAdmin)
         smart_register(Permission)(PermissionAdmin)
